The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {refuginator}


Title: An Interactive Tool for Identifying Refugia
Version: 1.0.2
Description: A 'shiny'-based browser application for reconstructing organismal distributions and identifying historical and geohistorical refugia using the methods published by Morley et al. (2026) <doi:10.1038/s43247-026-03563-3>.
License: GPL (≥ 3)
Encoding: UTF-8
Imports: dplyr, gganimate, ggplot2, leaflet, neotoma2, plotly, rlang, rnaturalearth, rnaturalearthdata, scales, sf, shiny, shinycssloaders, shinyjs, stringr, tidyr, viridis
RoxygenNote: 7.3.3
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
VignetteBuilder: knitr
URL: https://github.com/nathanielmorley2000/refuginator
BugReports: https://github.com/nathanielmorley2000/refuginator/issues
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-09-05 05:34:30 UTC; dinom
Author: Nathaniel E. D. Morley ORCID iD [aut, cre, cph]
Maintainer: Nathaniel E. D. Morley <nathaniel.morley2000@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-15 10:30:02 UTC

Launch the Refuginator Application in your Browser

Description

Launch the Refuginator Application in your Browser

Usage

launchRefuginator(defaultbrowser = TRUE)

Arguments

defaultbrowser

Choose whether to launch the application in your default browser.

Value

Launches Refuginator application in your browser. All features are contained within the application. Read the "refuginatorIntro" vignette for a guide to the features.

Examples

if (interactive()) {
  launchRefuginator()
}

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.